==> gi-assets-algorithm-2.2.4.tgz: package/es/NodesSimilarity/resultTable.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
// @ts-nocheck
import { DownloadOutlined } from '@ant-design/icons';
import { Table, Tooltip } from 'antd';
import React, { useEffect, useState } from 'react';
import { exportCSV, formatFileName } from '../utils/csv';
import { NodesSimilarityAlgorithm } from './Component';
import FormattedMessage, { formatMessage } from './locale';
var ClustersResultTable = function ClustersResultTable(_ref) {
  var similarNodes = _ref.similarNodes,
    _ref$similarityKey = _ref.similarityKey,
    similarityKey = _ref$similarityKey === void 0 ? 'similarity' : _ref$similarityKey,
    topReset = _ref.topReset;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    sortOrder = _useState2[0],
    setSortOrder = _useState2[1];
  useEffect(function () {
    setSortOrder(false);
  }, [topReset]);
  var formatSimilar = function formatSimilar(value) {
    return Number("".concat(value).slice(0, 7));
  };
  var propertiesKeys = [];
  var resData = [];
  similarNodes === null || similarNodes === void 0 ? void 0 : similarNodes.forEach(function (node, index) {
    if (!node.properties) {
      return;
    }
    propertiesKeys.push('id');
    propertiesKeys = propertiesKeys.concat(Object.keys(node.properties));
    resData.push(Object.assign(Object.assign({}, node.properties), {
      index: index,
      label: node.label,
      similarity: node[similarityKey] ? formatSimilar(node[similarityKey]) : '-',
      id: node.id
    }));
  });
  propertiesKeys = Array.from(new Set(propertiesKeys));
  var columns = [{
    title: /*#__PURE__*/React.createElement(FormattedMessage, {
      id: 'index'
    }),
    dataIndex: 'index',
    key: 'index',
    width: 60,
    fixed: 'left'
  }, {
    title: /*#__PURE__*/React.createElement(FormattedMessage, {
      id: 'node-name'
    }),
    dataIndex: 'label',
    key: 'label',
    textWrap: 'word-break',
    ellipsis: true,
    fixed: 'left',
    width: 100
  }, {
    title: /*#__PURE__*/React.createElement(FormattedMessage, {
      id: 'node-id'
    }),
    dataIndex: 'id',
    key: 'id',
    textWrap: 'word-break',
    ellipsis: true,
    // fixed: 'left',
    width: 100
  }, {
    title: /*#__PURE__*/React.createElement(FormattedMessage, {
      id: "itelligent-analysis.nodes-similarity.table-title.".concat(NodesSimilarityAlgorithm.nodesConsineSimilarity)
    }),
    dataIndex: 'similarity',
    key: 'similarity',
    textWrap: 'word-break',
    // fixed: 'left',
    width: 120,
    sortOrder: sortOrder,
    sorter: function sorter(a, b) {
      return a.similarity - b.similarity;
    }
  }];
  propertiesKeys.forEach(function (propertyKey) {
    columns.push({
      title: propertyKey,
      dataIndex: propertyKey,
      key: propertyKey,
      width: 120,
      textWrap: 'word-break',
      ellipsis: true
    });
  });
  var onTableChange = function onTableChange(pagination, filters, sorter, extra) {
    if (extra.action === 'sort') {
      setSortOrder(sorter.order || false);
    }
  };
  var download = function download() {
    var fileName = formatFileName('similarity_result');
    exportCSV({
      data: resData,
      title: [formatMessage({
        id: 'index'
      }), formatMessage({
        id: 'node-name'
      }), formatMessage({
        id: "nodes-similarity.table-title.".concat(NodesSimilarityAlgorithm.nodesConsineSimilarity)
      })].concat(propertiesKeys),
      titleForKey: ['index', 'label', 'similarity'].concat(propertiesKeys)
    }, fileName);
  };
  var maxSimilarNode = similarNodes[1];
  var minSimilarNode = similarNodes[similarNodes.length - 1];
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Tooltip, {
    title: /*#__PURE__*/React.createElement(FormattedMessage, {
      id: "download-csv"
    }),
    placement: "topRight"
  }, /*#__PURE__*/React.createElement(DownloadOutlined, {
    style: {
      float: 'right'
    },
    onClick: download
  })), /*#__PURE__*/React.createElement("div", {
    className: "nodes-similarity-table-wrapper"
  }, /*#__PURE__*/React.createElement("div", {
    className: "nodes-similarity-statistic"
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("span", null, /*#__PURE__*/React.createElement(FormattedMessage, {
    id: "max"
  }), ":", ' '), /*#__PURE__*/React.createElement("span", {
    className: "nodes-similarity-statistic-value"
  }, formatSimilar(maxSimilarNode[similarityKey]), "\uFF08", maxSimilarNode === null || maxSimilarNode === void 0 ? void 0 : maxSimilarNode.label, "\uFF09")), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("span", null, /*#__PURE__*/React.createElement(FormattedMessage, {
    id: "min"
  }), ":", ' '), /*#__PURE__*/React.createElement("span", {
    className: "nodes-similarity-statistic-value"
  }, formatSimilar(minSimilarNode[similarityKey]), "\uFF08", minSimilarNode === null || minSimilarNode === void 0 ? void 0 : minSimilarNode.label, "\uFF09"))), /*#__PURE__*/React.createElement(Table, {
    dataSource: resData,
    columns: columns,
    size: "small",
    showSorterTooltip: {
      title: formatMessage({
        id: 'sort'
      })
    },
    scroll: {
      x: 200
    },
    onChange: onTableChange
  })));
};
export default ClustersResultTable;

==> gi-assets-algorithm-2.3.9.tgz: package/es/NodesSimilarity/resultTable.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
// @ts-nocheck
import { DownloadOutlined } from '@ant-design/icons';
import { Table, Tooltip } from 'antd';
import React, { useEffect, useState } from 'react';
import { exportCSV, formatFileName } from '../utils/csv';
import $i18n from '../i18n';
var ClustersResultTable = function ClustersResultTable(_ref) {
  var similarNodes = _ref.similarNodes,
    _ref$similarityKey = _ref.similarityKey,
    similarityKey = _ref$similarityKey === void 0 ? 'similarity' : _ref$similarityKey,
    topReset = _ref.topReset;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    sortOrder = _useState2[0],
    setSortOrder = _useState2[1];
  useEffect(function () {
    setSortOrder(false);
  }, [topReset]);
  var formatSimilar = function formatSimilar(value) {
    return Number("".concat(value).slice(0, 7));
  };
  var propertiesKeys = [];
  var resData = [];
  similarNodes === null || similarNodes === void 0 ? void 0 : similarNodes.forEach(function (node, index) {
    if (!node.properties) {
      return;
    }
    propertiesKeys.push('id');
    propertiesKeys = propertiesKeys.concat(Object.keys(node.properties));
    resData.push(Object.assign(Object.assign({}, node.properties), {
      index: index,
      label: node.label,
      similarity: node[similarityKey] ? formatSimilar(node[similarityKey]) : '-',
      id: node.id
    }));
  });
  propertiesKeys = Array.from(new Set(propertiesKeys));
  var columns = [{
    title: $i18n.get({
      id: 'gi-assets-algorithm.src.NodesSimilarity.resultTable.SerialNumber',
      dm: '序号'
    }),
    dataIndex: 'index',
    key: 'index',
    width: 60,
    fixed: 'left'
  }, {
    title: $i18n.get({
      id: 'gi-assets-algorithm.src.NodesSimilarity.resultTable.NodeName',
      dm: '节点名称'
    }),
    dataIndex: 'label',
    key: 'label',
    textWrap: 'word-break',
    ellipsis: true,
    fixed: 'left',
    width: 100
  }, {
    title: $i18n.get({
      id: 'gi-assets-algorithm.src.NodesSimilarity.resultTable.NodeId',
      dm: '节点 ID'
    }),
    dataIndex: 'id',
    key: 'id',
    textWrap: 'word-break',
    ellipsis: true,
    // fixed: 'left',
    width: 100
  }, {
    title: $i18n.get({
      id: 'gi-assets-algorithm.src.NodesSimilarity.resultTable.CosineSimilarity',
      dm: '余弦相似度'
    }),
    dataIndex: 'similarity',
    key: 'similarity',
    textWrap: 'word-break',
    // fixed: 'left',
    width: 120,
    sortOrder: sortOrder,
    sorter: function sorter(a, b) {
      return a.similarity - b.similarity;
    }
  }];
  propertiesKeys.forEach(function (propertyKey) {
    columns.push({
      title: propertyKey,
      dataIndex: propertyKey,
      key: propertyKey,
      width: 120,
      textWrap: 'word-break',
      ellipsis: true
    });
  });
  var onTableChange = function onTableChange(pagination, filters, sorter, extra) {
    if (extra.action === 'sort') {
      setSortOrder(sorter.order || false);
    }
  };
  var download = function download() {
    var fileName = formatFileName('similarity_result');
    exportCSV({
      data: resData,
      title: [$i18n.get({
        id: 'gi-assets-algorithm.src.NodesSimilarity.resultTable.SerialNumber',
        dm: '序号'
      }), $i18n.get({
        id: 'gi-assets-algorithm.src.NodesSimilarity.resultTable.NodeName',
        dm: '节点名称'
      }), $i18n.get({
        id: 'gi-assets-algorithm.src.NodesSimilarity.resultTable.CosineSimilarity',
        dm: '余弦相似度'
      })].concat(propertiesKeys),
      titleForKey: ['index', 'label', 'similarity'].concat(propertiesKeys)
    }, fileName);
  };
  var maxSimilarNode = similarNodes[1];
  var minSimilarNode = similarNodes[similarNodes.length - 1];
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Tooltip, {
    title: $i18n.get({
      id: 'gi-assets-algorithm.src.NodesSimilarity.resultTable.DownloadCsv',
      dm: '下载 CSV'
    }),
    placement: "topRight"
  }, /*#__PURE__*/React.createElement(DownloadOutlined, {
    style: {
      float: 'right'
    },
    onClick: download
  })), /*#__PURE__*/React.createElement("div", {
    className: "nodes-similarity-table-wrapper"
  }, /*#__PURE__*/React.createElement("div", {
    className: "nodes-similarity-statistic"
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("span", null, $i18n.get({
    id: 'gi-assets-algorithm.src.NodesSimilarity.resultTable.MaximumValue',
    dm: '最大值:'
  })), /*#__PURE__*/React.createElement("span", {
    className: "nodes-similarity-statistic-value"
  }, formatSimilar(maxSimilarNode[similarityKey]), "\uFF08", maxSimilarNode === null || maxSimilarNode === void 0 ? void 0 : maxSimilarNode.label, "\uFF09")), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("span", null, $i18n.get({
    id: 'gi-assets-algorithm.src.NodesSimilarity.resultTable.MinimumValue',
    dm: '最小值:'
  })), /*#__PURE__*/React.createElement("span", {
    className: "nodes-similarity-statistic-value"
  }, formatSimilar(minSimilarNode[similarityKey]), "\uFF08", minSimilarNode === null || minSimilarNode === void 0 ? void 0 : minSimilarNode.label, "\uFF09"))), /*#__PURE__*/React.createElement(Table, {
    dataSource: resData,
    columns: columns,
    size: "small",
    showSorterTooltip: {
      title: $i18n.get({
        id: 'gi-assets-algorithm.src.NodesSimilarity.resultTable.Sort',
        dm: '排序'
      })
    },
    scroll: {
      x: 200
    },
    onChange: onTableChange
  })));
};
export default ClustersResultTable;
